==========
Sir Django
==========

Sir Trevor integration for Django

Installing
==========

Install using pip::

    pip install sirdjango

It works with Python 2.7+, and Django 1.7+

Using
=====

TODO
